ArchetypeManagerBigInt class

Implemented types

Constructors

ArchetypeManagerBigInt(Iterable<Type> types)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getArchetype(Iterable<Type> componentTypes) Archetype
override
getComponentTypes(Archetype archetype) Iterable<Type>
override
getTypeIndex(Type type) int?
override
isSubtype(Archetype a, Archetype b) bool
override
isSupertype(Archetype a, Archetype b) bool
override
matches(Iterable<Type> componentTypes) bool
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited