ArchetypeManagerInterface class abstract

Implementers

Constructors

ArchetypeManagerInterface()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getArchetype(Iterable<Type> componentTypes) Archetype
getComponentTypes(Archetype archetype) Iterable<Type>
getTypeIndex(Type type) int?
isSubtype(Archetype a, Archetype b) bool
isSupertype(Archetype a, Archetype b) bool
matches(Iterable<Type> componentTypes) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited