ArchetypeStats class

Constructors

ArchetypeStats()

Properties

entityCounts Map<Archetype, int>
no setter
hashCode int
The hash code for this object.
no setterinherited
recycleBinSizes Map<Archetype, int>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalArchetypes int
no setter
totalEntities int
no setter
totalInRecycleBin int
no setter

Methods

getMostUsedArchetypes({int limit = 10}) List<ArchetypeEntry>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset() → void
snapshot() ArchetypeStatsSnapshot
toString() String
A string representation of this object.
override
updateEntityCount(Archetype archetype, int count) → void
updateRecycleBinSize(Archetype archetype, int size) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited