ArchetypeStatsSnapshot class

Constructors

ArchetypeStatsSnapshot({required Map<Archetype, int> entityCounts, required Map<Archetype, int> recycleBinSizes})
const

Properties

entityCounts Map<Archetype, int>
final
hashCode int
The hash code for this object.
no setterinherited
recycleBinSizes Map<Archetype, int>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalArchetypes int
no setter
totalEntities int
no setter
totalInRecycleBin int
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited