ComponentManagerInterface class abstract

Inheritance
Implementers

Constructors

ComponentManagerInterface()

Properties

componentTypes Iterable<Type>
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addComponents(Entity entity, Iterable<Component> components) → void
getComponent<T extends Component>(Entity entity) → T?
inherited
getComponentByType(Type componentType, Entity entity) Component?
inherited
getComponents(Entity entity) Iterable<Component>
inherited
getComponentsOfType<T extends Component>() Iterable<T>
inherited
hasComponent<T>(Entity entity) bool
inherited
hasComponentByType(Entity entity, Type type) bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeAllComponents(Entity entity) → void
removeComponentByType<T extends Component>(Entity entity) → void
removeComponentsByType(Entity entity, Iterable<Type> componentTypes) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited