ComponentManagerReadOnlyInterface class abstract

Implementers

Properties

componentTypes Iterable<Type>
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getComponent<T extends Component>(Entity entity) → T?
getComponentByType(Type componentType, Entity entity) Component?
getComponents(Entity entity) Iterable<Component>
getComponentsOfType<T extends Component>() Iterable<T>
hasComponent<T>(Entity entity) bool
hasComponentByType(Entity entity, Type type) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited