ComponentSerializer<T> class abstract

Constructors

ComponentSerializer()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

canDeserialize(ComponentRepresentation data) bool
canSerialize(Object component) bool
deserialize(ComponentRepresentation data) → T
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(T component) ComponentRepresentation?
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited