EntityFactory class

Constructors

EntityFactory({required Iterable<EntityPrefab> prefabs})

Properties

hashCode int
The hash code for this object.
no setterinherited
prefabs Map<String, EntityPrefab>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addPrefab(EntityPrefab prefab) → void
fabricate(String name, World world) Entity
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removePrefab(String name) → void
replacePrefab(EntityPrefab prefab) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited