EntityManager class

Implemented types
Available extensions

Constructors

EntityManager(ComponentManager _componentManager)

Properties

componentManager ComponentManager
no setter
entities Iterable<Entity>
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
viewCacheSize int
no setter

Methods

addComponents(Entity entity, Iterable<Component> components) → void
addObserver(EntityManagerListener observer) → void
clearViewCache() → void
cloneEntity(Entity entity) Entity
createEntity(Iterable<Component> components) Entity
destroyEntity(Entity entity) → void
getArchetype(Entity entity) Archetype?
getEntitiesMatching(Archetype archetype) Iterable<Entity>
getEntitiesWithComponents(Set<Type> types) Iterable<Entity>
getOrCreateView(Archetype archetype) EntityView
hasEntity(Entity entity) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onEntityArchetypeChanged(Entity entity, Archetype newArchetype, Archetype oldArchetype) → void
override
onEntityCreated(Entity entity) → void
override
onEntityWillDestroy(Entity entity) → void
override
processCreationQueue() → void
processDeletionQueue() → void
removeComponents(Entity entity, Iterable<Type> componentTypes) → void
removeObserver(EntityManagerListener observer) → void
setStats(EntityStats? entityStats, ArchetypeStats? archetypeStats) → void
toString() String
A string representation of this object.
inherited
updateArchetypeStats() → void
view(Archetype archetype) EntityView

Available on EntityManager, provided by the EntityViewOnEntityManager extension

viewForTypes(Set<Type> types) EntityView

Available on EntityManager, provided by the EntityViewOnEntityManager extension

Operators

operator ==(Object other) bool
The equality operator.
inherited