EntityManagerListener class abstract

Implementers

Constructors

EntityManagerListener()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onEntityArchetypeChanged(Entity entity, Archetype newArchetype, Archetype oldArchetype) → void
onEntityCreated(Entity entity) → void
onEntityWillDestroy(Entity entity) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited