EntitySerialiser class abstract

Implementers

Constructors

EntitySerialiser(EntityManager _entityManager, Map<Type, ComponentSerializer> serializers)

Properties

componentsSerializer EntityComponentsSerializer
latefinal
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

deserializeEntity(EntityRepresentation data) Entity
deserializeEntityComponents(EntityRepresentation data) Iterable<ComponentRepresentation>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serializeEntity(Entity entity) EntityRepresentation
serializeEntityComponents(Entity entity, Iterable<ComponentRepresentation> components) EntityRepresentation
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited