EntityStatsSnapshot class

Constructors

EntityStatsSnapshot({required int totalCreated, required int totalDestroyed, required int activeCount, required int recycledCount, required int peakCount, required int creationQueueSize, required int deletionQueueSize})
const

Properties

activeCount int
final
creationQueueSize int
final
deletionQueueSize int
final
hashCode int
The hash code for this object.
no setterinherited
peakCount int
final
recycledCount int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalCreated int
final
totalDestroyed int
final

Methods

diff(EntityStatsSnapshot other) EntityStatsSnapshot
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited