EntitySystem class abstract

Inheritance

Constructors

EntitySystem()

Properties

componentManager ComponentManagerReadOnlyInterface
latefinalinherited
entityManager EntityManager
latefinalinherited
filterTypes Set<Type>
no setter
hashCode int
The hash code for this object.
no setterinherited
name String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
view EntityView
latefinal
world World
no setterinherited

Methods

attach(EntityManager entityManager) → void
override
attachWorld(World world) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
process(Duration delta) → void
override
processEntity(Entity entity, ComponentManagerReadOnlyInterface componentManager, Duration delta) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited