System class abstract

Implementers

Constructors

System()

Properties

componentManager ComponentManagerReadOnlyInterface
latefinal
entityManager EntityManager
latefinal
hashCode int
The hash code for this object.
no setterinherited
name String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
world World
no setter

Methods

attach(EntityManager entityManager) → void
attachWorld(World world) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
process(Duration delta) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited