SystemStats class

Constructors

SystemStats(String name)

Properties

averageTimeMicros double
no setter
averageTimeMs double
no setter
callCount int
no setter
hashCode int
The hash code for this object.
no setterinherited
maxTime Duration
no setter
minTime Duration
no setter
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalEntitiesProcessed int
no setter
totalTime Duration
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
recordExecution(Duration duration, int entitiesProcessed) → void
reset() → void
snapshot() SystemStatsSnapshot
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited