SystemStatsSnapshot class

Constructors

SystemStatsSnapshot({required String name, required int callCount, required int totalEntitiesProcessed, required Duration totalTime, required Duration minTime, required Duration maxTime})
const

Properties

averageTimeMicros double
no setter
averageTimeMs double
no setter
callCount int
final
hashCode int
The hash code for this object.
no setterinherited
maxTime Duration
final
minTime Duration
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalEntitiesProcessed int
final
totalTime Duration
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited