World class

Available extensions

Constructors

World(ComponentManager _componentManager, EntityManager _entityManager, List<System> _systems, {bool enableStats = false})

Properties

entityManager EntityManager
no setter
frameCount int
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stats WorldStats?
final
worldTime Duration
no setter

Methods

addComponents(Entity entity, Iterable<Component> components) → void
cloneEntity(Entity entity) int
createEntity(Iterable<Component> components) int
destroyEntity(Entity entity) → void
flushEntityQueues() → void
getComponent<T extends Component>(Entity entity) → T?
getSystem<T extends System>() → T?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
process({Duration delta = const Duration(milliseconds: 16)}) → void
removeComponents(Entity entity, Iterable<Type> componentTypes) → void
toString() String
A string representation of this object.
inherited
view(Archetype archetype, {bool autoFlush = true}) EntityView

Available on World, provided by the EntityViewOnWorld extension

viewForTypes(Set<Type> types, {bool autoFlush = true}) EntityView

Available on World, provided by the EntityViewOnWorld extension

Operators

operator ==(Object other) bool
The equality operator.
inherited