WorldSerialiserJson class
- Inheritance
-
- Object
- WorldSerialiser
- WorldSerialiserJson
Constructors
- WorldSerialiserJson(World entityManager, EntitySerialiser serializers)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
deserialize(
WorldRepresentation data) → Iterable< Entity> -
inherited
-
deserializeEntities(
WorldRepresentation data) → Iterable< EntityRepresentation> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
) → WorldRepresentation -
inherited
-
serializeEntities(
Iterable< EntityRepresentation> entities) → WorldRepresentation -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- entitiesField → const String