toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  final buffer = StringBuffer();
  buffer.writeln('WorldStatsSnapshot:');
  buffer.writeln('  Frames: $frameCount');
  buffer.writeln('  World Time: ${worldTime.inSeconds.toStringAsFixed(3)}s');
  buffer.writeln('  $entities');
  buffer.writeln('  $archetypes');
  if (systems.isNotEmpty) {
    buffer.writeln('  Systems:');
    for (var system in systems.values) {
      buffer.writeln('    $system');
    }
  }
  return buffer.toString();
}