ComponentManagerListener class abstract
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onComponentAdded(
Entity entity, Component component) → void -
onComponentReplaced(
Entity entity, Component oldComponent, Component newComponent) → void -
onComponentWillRemove(
Entity entity, Component component) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited