EntityComponentsSerializer class
Constructors
-
EntityComponentsSerializer(Map<
Type, ComponentSerializer> _serializers)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
deserializeComponent(
ComponentRepresentation data) → Component -
deserializeComponents(
Iterable< ComponentRepresentation> data) → Iterable<Component> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serializeComponent(
Component component) → ComponentRepresentation? -
serializeComponents(
Iterable< Component> components) → Iterable<ComponentRepresentation> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited