EntitySerialiserJson class
- Inheritance
-
- Object
- EntitySerialiser
- EntitySerialiserJson
Constructors
-
EntitySerialiserJson(EntityManager entityManager, Map<
Type, ComponentSerializer> serializers)
Properties
- componentsSerializer ↔ EntityComponentsSerializer
-
latefinalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
deserializeEntity(
EntityRepresentation data) → Entity -
inherited
-
deserializeEntityComponents(
EntityRepresentation data) → Iterable< ComponentRepresentation> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serializeEntity(
Entity entity) → EntityRepresentation -
inherited
-
serializeEntityComponents(
Entity entity, Iterable< ComponentRepresentation> components) → EntityRepresentation -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- componentsField → const String
- typeField → const String