EntityStats class
Constructors
Properties
- activeCount → int
-
no setter
- creationQueueSize → int
-
no setter
- deletionQueueSize → int
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- peakCount → int
-
no setter
- recycledCount → int
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalCreated → int
-
no setter
- totalDestroyed → int
-
no setter
Methods
-
incrementCreated(
) → void -
incrementDestroyed(
) → void -
incrementRecycled(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reset(
) → void -
snapshot(
) → EntityStatsSnapshot -
toString(
) → String -
A string representation of this object.
override
-
updateCreationQueueSize(
int size) → void -
updateDeletionQueueSize(
int size) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited