EntityStatsSnapshot class
Constructors
Properties
- activeCount → int
-
final
- creationQueueSize → int
-
final
- deletionQueueSize → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- peakCount → int
-
final
- recycledCount → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalCreated → int
-
final
- totalDestroyed → int
-
final
Methods
-
diff(
EntityStatsSnapshot other) → EntityStatsSnapshot -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited