WorldSerialiser class abstract
- Implementers
Constructors
- WorldSerialiser(World world, EntitySerialiser _entitySerialiser)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
deserialize(
WorldRepresentation data) → Iterable< Entity> -
deserializeEntities(
WorldRepresentation data) → Iterable< EntityRepresentation> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
) → WorldRepresentation -
serializeEntities(
Iterable< EntityRepresentation> entities) → WorldRepresentation -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited