WorldStats class
Constructors
Properties
- archetypes → ArchetypeStats
-
final
- entities → EntityStats
-
final
- frameCount → int
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
systems
→ List<
SystemStats> -
no setter
- worldTime → Duration
-
no setter
Methods
-
getOrCreateSystemStats(
String systemName) → SystemStats -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reset(
) → void -
setFrameCount(
int count) → void -
setWorldTime(
Duration time) → void -
snapshot(
) → WorldStatsSnapshot -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited