WorldStatsSnapshot class
Constructors
-
WorldStatsSnapshot({required EntityStatsSnapshot entities, required ArchetypeStatsSnapshot archetypes, required Map<
String, SystemStatsSnapshot> systems, required int frameCount, required Duration worldTime}) -
const
Properties
- archetypes → ArchetypeStatsSnapshot
-
final
- entities → EntityStatsSnapshot
-
final
- frameCount → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
systems
→ Map<
String, SystemStatsSnapshot> -
final
- worldTime → Duration
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited